@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
 
 from .mit import MITDynamics
-from .materials_project import MatProjDynamics
+from .materials_project import MatprojDynamics
 from .materials_virtual_lab_npt import MatVirtualLabNPTDynamics
