@@ -38,6 +38,7 @@ from simmate.calculators.vasp.error_handlers import (
     PositiveEnergy,
     Frozen,
     LargeSigma,
+    Walltime,
 )
 
 
@@ -195,4 +196,5 @@ class MatprojRelaxation(VaspTask):
         PositiveEnergy(),
         Frozen(),
         LargeSigma(),
+        Walltime(),
     ]
