@@ -8,11 +8,11 @@ See the `simmate.database.base_data_types` (which is the parent module of
 this one) for example usage.
 """
 
-
 import os
 import inspect
 import shutil
 import urllib
+import warnings
 
 import yaml
 
@@ -300,7 +300,7 @@ class DatabaseTable(models.Model):
     ``` python
     # from a thirdparty database or separate table
     source = {
-        "table": "MatProjStructure",
+        "table": "MatprojStructure",
         "id": "mp-123",
     }
     
@@ -317,14 +317,14 @@ class DatabaseTable(models.Model):
     # from a transformation
     source = {
         "method": "MirrorMutation",
-        "table": "MatProjStructure",
+        "table": "MatprojStructure",
         "id": "mp-123",
     }
     
     # from a multi-structure transformation
     source = {
         "method": "HereditaryMutation",
-        "table": "MatProjStructure",
+        "table": "MatprojStructure",
         "ids": ["mp-123", "mp-321"],
     }
     ```
@@ -541,6 +541,20 @@ class DatabaseTable(models.Model):
         # return the dictionary
         return all_data if as_dict else cls(**all_data)
 
+    def update_from_toolkit(self, **kwargs):
+        """
+        Given fundamental "base_info" and toolkit objects, this method will populate
+        all relevant columns.
+
+        This method is meant for updating existing database entries with new
+        data. If your creating a brand-new database entry, use the
+        `from_toolkit` method instead.
+        """
+        new_kwargs = self.from_toolkit(as_dict=True, **kwargs)
+        for new_kwarg, new_value in new_kwargs.items():
+            setattr(self, new_kwarg, new_value)
+        self.save()
+
     @classmethod
     def _confirm_override(
         cls,
@@ -652,6 +666,10 @@ class DatabaseTable(models.Model):
             Default is False.
         """
 
+        # We disable warnings while loading archives because pymatgen prints
+        # a lot of them (for things like rounding or electronegativity alerts).
+        warnings.filterwarnings("ignore")
+
         # make sure the user actually wants to do this!
         cls._confirm_override(
             confirm_override,
