@@ -7,5 +7,6 @@ __doc__ = get_doc_from_readme(__file__)
 from .aflow import AflowStructure, AflowPrototype
 from .cod import CodStructure
 from .jarvis import JarvisStructure
-from .materials_project import MatProjStructure
+from .materials_project import MatprojStructure
 from .oqmd import OqmdStructure
+from .utilities import load_remote_archives, load_default_sqlite3_build
