@@ -3,7 +3,7 @@
 from simmate.database.base_data_types import table_column, Structure, Thermodynamics
 
 
-class MatProjStructure(Structure, Thermodynamics):
+class MatprojStructure(Structure, Thermodynamics):
     """
     Crystal structures from the [Materials Project](https://materialsproject.org/)
     database.
