@@ -6,6 +6,15 @@ from pymatgen.analysis.diffusion.neb.pathfinder import (
 
 
 class MigrationHop(PymatgenMigrationHop):
+    def as_dict(self):
+        # Pymatgen.diffusion has a broken as_dict method, so I need to fix this
+        # here. I don't want to raise an error because I don't want issues
+        # with the higher-level serialize_parameters utility
+        return (
+            "MigrationHop is not MSONable, and this bug is within pymatgen diffusion."
+            "See https://github.com/materialsvirtuallab/pymatgen-analysis-diffusion/pull/264"
+        )
+
     @classmethod
     def from_dynamic(cls, migration_hop):
         """
@@ -24,7 +33,7 @@ class MigrationHop(PymatgenMigrationHop):
             and "migration_hop_table" in migration_hop.keys()
         ):
             is_from_past_calc = True
-            migration_hop_cleaned = cls.from_database(migration_hop)
+            migration_hop_cleaned = cls.from_database_dict(migration_hop)
         else:
             raise Exception("Unknown format provided for migration_hop input.")
         migration_hop_cleaned.is_from_past_calc = is_from_past_calc
@@ -32,7 +41,7 @@ class MigrationHop(PymatgenMigrationHop):
         return migration_hop_cleaned
 
     @classmethod
-    def from_database(cls, migration_hop: dict):
+    def from_database_dict(cls, migration_hop: dict):
         """
         This is an experimental feature. The code here is a repurposing of
         Structre.from_dynamic so consider making a general class for
