@@ -5,7 +5,7 @@
 # https://docs.djangoproject.com/en/3.1/topics/db/models/#organizing-models-in-a-package
 
 from simmate.database.third_parties import (
-    MatProjStructure,
+    MatprojStructure,
     JarvisStructure,
     AflowStructure,
     AflowPrototype,
