@@ -9,12 +9,11 @@ __doc__ = get_doc_from_readme(__file__)
 # module, so it may be worth isolating them for faster imports.
 from .error_handler import ErrorHandler
 from .supervised_staged_shell_task import S3Task
+from .worker import Worker
 
 # All imports below this point depend on the simmate.database module and therefore
 # need a database connection. This line sets up the database connection so
 # that models can be imported.
 from simmate.database import connect
 
-from .workflow_task import WorkflowTask
-from .workflow import Workflow, Parameter, ModuleStorage, task, Task
-from .utilities import s3task_to_workflow
+from .workflow import Workflow, task
