@@ -339,6 +339,7 @@ class Workflow:
         copy_previous_directory: bool = False,
         pre_sanitize_structure: bool = None,
         pre_standardize_structure: bool = None,
+        is_restart: bool = False,
     ):
         """
         The workflow method, which can be overwritten when inheriting from this
@@ -383,6 +384,7 @@ class Workflow:
             copy_previous_directory=copy_previous_directory,
             pre_sanitize_structure=pre_sanitize_structure,
             pre_standardize_structure=pre_standardize_structure,
+            is_restart=is_restart,
         ).result()
 
         result = cls.s3task.run(**parameters_cleaned).result()
@@ -421,7 +423,7 @@ class Workflow:
         A convience method to run a workflow as a subflow in a prefect context.
         """
         subflow = cls.to_prefect_flow()
-        state = subflow(**kwargs)
+        state = subflow(return_state=True, **kwargs)
 
         # We don't want to block and wait because this might disable parallel
         # features of subflows. We therefore return the state and let the
@@ -807,37 +809,32 @@ class Workflow:
         other methods when appropriate
         """
 
-        # CREATE_DEPLOYMENT method is not yet updated in 2.0b8
-        #
-        # async with get_client() as client:
-        #     response = await client.create_deployment(
-        #         name="leonardo-deployment",
-        #         flow_location="./leo_flow.py",
-        #         tags=['tutorial','test'],
-        #         parameters={'name':'Leo'},
-        #     )
-
-        # For now, this is a modification of the create_deployment code
-        # until they fix the method.
+        # raise error until python-deployments are supported again
+        raise Exception(
+            "Prefect 2.0 has removed the ability to create deployments in "
+            "python, so this feature is currently disabled."
+        )
+        # When this is removed, be sure to re-add the test_workflow_cloud unittest
 
         from prefect.deployments import Deployment
 
+        # NOTE: we do not use the client.create_deployment method because it
+        # is called within the Deployment.create() method for us.
         deployment = Deployment(
-            flow=cls.to_prefect_flow(),
             name=cls.name_full,
+            flow=cls.to_prefect_flow(),
             packager=OrionPackager(serializer=PickleSerializer()),
+            # OPTIMIZE: it would be better if I could figure out the ImportSerializer
+            # here. Only issue is that prefect would need to know to import AND
+            # call a method.
             tags=[
                 "simmate",
                 cls.name_project,
                 cls.name_calculator,
             ],
         )
-        # OPTIMIZE: it would be better if I could figure out the ImportSerializer
-        # here. Only issue is that prefect would need to know to import AND
-        # call a method.
 
-        async with get_client() as client:
-            deployment_id = await deployment.create()
+        deployment_id = await deployment.create()
 
         return str(deployment_id)  # convert from UUID to str first
 
